@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2011-2016 Horde LLC
+ * @copyright 2011-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2011-2016 Horde LLC
+ * @copyright 2011-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -84,6 +84,12 @@ class IMP_LoginTasks_Task_Autocreate extends Horde_LoginTasks_Task
                     'special_use' => array(Horde_Imap_Client::SPECIALUSE_TRASH)
                 ));
                 break;
+
+            case IMP_Mailbox::SPECIAL_USER:
+                foreach ($val as $mbox) {
+                    $mbox->create();
+                }
+                break;
             }
         }
     }
