@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2006-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2006-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2006-2016 Horde LLC
+ * @copyright 2006-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2006-2016 Horde LLC
+ * @copyright 2006-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -134,11 +134,17 @@ class IMP_Message_Ui
                     'from_addr' => $from
                 )
             );
-
             $maillog->log($log_msg, new IMP_Maillog_Log_Mdn());
-
             $success = true;
-        } catch (Exception $e) {}
+        } catch (Exception $e) {
+            $injector->getInstance('IMP_Sentmail')->log(
+                IMP_Sentmail::MDN,
+                '',
+                $return_addr,
+                $success
+            );
+            throw $e;
+        }
 
         $injector->getInstance('IMP_Sentmail')->log(
             IMP_Sentmail::MDN,
