@@ -1,6 +1,6 @@
 <form name="fmanager" method="post" action="<?php echo $this->folders_url ?>">
  <?php echo $this->hiddenFieldTag('actionID', $this->actionID) ?>
- <?php echo $this->hiddenFieldTag('folders_token', $this->folders_token) ?>
+ <?php echo $this->hiddenFieldTag('token', $this->token) ?>
 
  <div class="header leftAlign">
   <?php echo _("Folder Actions - Confirmation") ?>
